@@ -1,10 +1,11 @@
 from wtforms.fields import Field
 
-from flask.ext.wtf.recaptcha import widgets
-from flask.ext.wtf.recaptcha.validators import Recaptcha
+from . import widgets
+from .validators import Recaptcha
 
 __all__ = ["RecaptchaField"]
 
+
 class RecaptchaField(Field):
     widget = widgets.RecaptchaWidget()
 
@@ -13,4 +14,4 @@ class RecaptchaField(Field):
 
     def __init__(self, label='', validators=None, **kwargs):
         validators = validators or [Recaptcha()]
-        super(RecaptchaField, self).__init__(label, validators, **kwargs)
+        super().__init__(label, validators, **kwargs)
